## dbt-snowflake 1.11.2 - February 11, 2026

### Features

- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))
- Add information on number of rows in CTAS ([#1531](https://github.com/dbt-labs/dbt-adapters/issues/1531))

### Fixes

- Fix record/replay support for cursor.stats attribute access. ([#1573](https://github.com/dbt-labs/dbt-adapters/issues/1573))

### Contributors
- [@b-per](https://github.com/b-per) ([#1531](https://github.com/dbt-labs/dbt-adapters/issues/1531))
